@@ -619,6 +619,7 @@ main (int argc, char *argv[])
 #ifdef MINGW
   		ShutdownWinEnv();
 #endif
+      free (print);
       return -1;
     }
 
@@ -679,7 +680,7 @@ main (int argc, char *argv[])
       if (grepfriendly == YES)
 	printf ("%s ", argv[i]);
       else
-	printf (_("Keywords for file %s:"),
+	printf (_("Keywords for file %s:\n"),
 		argv[i]);
     }
     if (bibtex == YES)
