@@ -1,6 +1,6 @@
 /*
      This file is part of libextractor.
-     (C) 2002, 2003, 2004, 2006 Vidyut Samanta and Christian Grothoff
+     (C) 2002, 2003, 2004, 2006, 2009 Vidyut Samanta and Christian Grothoff
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -42,7 +42,7 @@ addKeyword (EXTRACTOR_KeywordList * oldhead,
 {
   EXTRACTOR_KeywordList *keyword;
 
-  keyword = (EXTRACTOR_KeywordList *) malloc (sizeof (EXTRACTOR_KeywordList));
+  keyword = malloc (sizeof (EXTRACTOR_KeywordList));
   keyword->next = oldhead;
   keyword->keyword = phrase;
   keyword->keywordType = type;
@@ -181,18 +181,19 @@ libextractor_id3v24_extract (const char *filename,
               /* this byte describes the encoding
                  try to convert strings to UTF-8
                  if it fails, then forget it */
+              csize--;
               switch (data[pos + 10])
                 {
                 case 0x00:
-                  word = convertToUtf8 ((const char *) &data[pos + 11],
+                  word = EXTRACTOR_common_convert_to_utf8 ((const char *) &data[pos + 11],
                                         csize, "ISO-8859-1");
                   break;
                 case 0x01:
-                  word = convertToUtf8 ((const char *) &data[pos + 11],
+                  word = EXTRACTOR_common_convert_to_utf8 ((const char *) &data[pos + 11],
                                         csize, "UTF-16");
                   break;
                 case 0x02:
-                  word = convertToUtf8 ((const char *) &data[pos + 11],
+                  word = EXTRACTOR_common_convert_to_utf8 ((const char *) &data[pos + 11],
                                         csize, "UTF-16BE");
                   break;
                 case 0x03:
@@ -203,12 +204,11 @@ libextractor_id3v24_extract (const char *filename,
                 default:
                   /* bad encoding byte,
                      try to convert from iso-8859-1 */
-                  word = convertToUtf8 ((const char *) &data[pos + 11],
+                  word = EXTRACTOR_common_convert_to_utf8 ((const char *) &data[pos + 11],
                                         csize, "ISO-8859-1");
                   break;
                 }
               pos++;
-              csize--;
               if ((word != NULL) && (strlen (word) > 0))
                 {
                   prev = addKeyword (prev, word, tmap[i].type);
