@@ -131,17 +131,17 @@ libextractor_id3v2_extract (const char *filename,
               switch (data[pos + 6])
                 {
                 case 0x00:
-                  word = convertToUtf8 ((const char *) &data[pos + 7],
+                  word = EXTRACTOR_common_convert_to_utf8 ((const char *) &data[pos + 7],
                                         csize, "ISO-8859-1");
                   break;
                 case 0x01:
-                  word = convertToUtf8 ((const char *) &data[pos + 7],
+                  word = EXTRACTOR_common_convert_to_utf8 ((const char *) &data[pos + 7],
                                         csize, "UCS-2");
                   break;
                 default:
                   /* bad encoding byte,
                      try to convert from iso-8859-1 */
-                  word = convertToUtf8 ((const char *) &data[pos + 7],
+                  word = EXTRACTOR_common_convert_to_utf8 ((const char *) &data[pos + 7],
                                         csize, "ISO-8859-1");
                   break;
                 }
