@@ -29,6 +29,7 @@
 
 #include "platform.h"
 #include "extractor.h"
+#include <glib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #define THUMBSIZE 128
@@ -38,6 +39,8 @@
 void __attribute__ ((constructor)) ole_gobject_init (void)
 {
   g_type_init ();
+  if (! g_thread_supported () )
+    g_thread_init (NULL);
 }
 
 
@@ -145,11 +148,19 @@ libextractor_thumbnailgtk_extract (const char *filename,
       height = height * THUMBSIZE / width;
       width = THUMBSIZE;
     }
+  if ( (height == 0) || (width == 0) )
+    {
+      g_object_unref (in);
+      return prev;
+    }
   out = gdk_pixbuf_scale_simple (in, width, height, GDK_INTERP_BILINEAR);
   g_object_unref (in);
   thumb = NULL;
+  length = 0;
+  if (out == NULL)
+    return prev;
   if (!gdk_pixbuf_save_to_buffer (out, &thumb, &length, "png", NULL, 
-				  "compression", 9, NULL))
+				  "compression", "9", NULL))
     {
       g_object_unref (out);
       return prev;
